pub struct CreateUserSessionOptions {
pub user_uuid: Uuid,
pub ip: IpNetwork,
pub user_agent: CompactString,
}Fields
user_uuid: Uuidip: IpNetworkuser_agent: CompactStringTrait Implementations
Sourceimpl ComposeSchema for CreateUserSessionOptions
impl ComposeSchema for CreateUserSessionOptions
Sourceimpl<'de> Deserialize<'de> for CreateUserSessionOptions
impl<'de> Deserialize<'de> for CreateUserSessionOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateUserSessionOptions
impl ToSchema for CreateUserSessionOptions
Sourceimpl Validate for CreateUserSessionOptions
impl Validate for CreateUserSessionOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateUserSessionOptions
impl RefUnwindSafe for CreateUserSessionOptions
impl Send for CreateUserSessionOptions
impl Sync for CreateUserSessionOptions
impl Unpin for CreateUserSessionOptions
impl UnwindSafe for CreateUserSessionOptions